.. _user_guide_configuration_index:

Configuration and dataset utilities
=========================================

This section covers the skrub global configurations and dataset utilities.

.. toctree::
   :maxdepth: 2

   modules/configuration_and_utils/customizing_configuration
   modules/configuration_and_utils/deduplicate_categorical_data
   modules/configuration_and_utils/fetching_datasets
